@@ -18,7 +18,7 @@ class InterruptCommand < Gem::Command
   end
 
   def execute
-    raise Interrupt
+    raise Interrupt, "Interrupt exception"
   end
 
 end
@@ -27,21 +27,21 @@ class TestProcessCommands < Test::Unit::TestCase
   include Gem::DefaultUserInteraction
 
   def setup
-    @cmd_manager = Gem::CommandManager.new
+    @command_manager = Gem::CommandManager.new
   end
 
   def test_query_command
     use_ui(MockGemUi.new) do
-      @cmd_manager.process_args "query"
-      assert_match /LOCAL GEMS/, ui.output
+      @command_manager.process_args "query"
+      assert_match(/LOCAL GEMS/, ui.output)
     end
   end
 
   def test_run_interrupt
     use_ui(MockGemUi.new) do
-      @cmd_manager.register_command InterruptCommand.new
+      @command_manager.register_command :interrupt
       assert_raises MockGemUi::TermError do
-        @cmd_manager.run 'interrupt'
+        @command_manager.run 'interrupt'
       end
       assert_equal '', ui.output
       assert_equal "ERROR:  Interrupted\n", ui.error
